@@ -386,7 +386,8 @@ class SFWA(StructureFolderWalkingAdapter):
                             written = False
                         #debug self.out.append(
                         #   'convert %s to %s and add with %s' % (invalue, value, mutator))
-                if not written:
+                #NB: Plone 4.3.3 relatedItems not used so no mutator hence dont report as bug        
+                if not written and name != 'relatedItems':
                     self.out.append('Failed to update %s %s.%s = %s' % (subdir,
                                                      obj.getId(), name, value))
                     
